@@ -34,6 +34,24 @@ If you do not set an API key, anyone will be able to view the data by
 visiting the widget URL.
 
 
+Encryption
+==========
+
+Geckoboard encryption allows encrypting data before it is sent to Geckoboard's 
+servers. After entering the password used to encrypt the data when the Geckoboard
+is loaded, the data will be decrypted in the browser.
+
+To use encryption, first set a password in the project ``settings.py`` file::
+
+    GECKOBOARD_PASSWORD = 'XXXXXXXXX'
+    
+Next, enable encryption for each widget using the decorator arguments::
+
+@number_widget(encrypted=True)
+    def user_count(request):
+        return User.objects.count()
+
+
 Creating custom widgets
 =======================
 
@@ -56,6 +74,13 @@ django-geckoboard decorator::
         midnight = datetime.combine(date.today(), time.min)
         return Comment.objects.filter(submit_date__gte=midnight).count()
 
+You can also specify the output format of the widget as either JSON or XML::
+
+   @number_widget(format='json')
+   def comment_count(request):
+        midnight = datatime.combine(date.today(), time.min)
+        return Comment.objects.filter(submit_data__get=midnight).count()
+
 
 If your widget has optional settings, you can pass them in the decorator
 definition::
@@ -79,6 +104,9 @@ This is all the Django code you need to display the comment count on
 your dashboard. When you create a custom widget in Geckoboard, enter the
 following information:
 
+Encryption
+    Enable if the field is encrypted (see instructions above).
+    
 URL data feed
     The view URL.  In the example above this would be something like
     ``http://HOSTNAME/geckoboard/comment_count/``.
@@ -91,8 +119,10 @@ Widget type
     *Custom*
 
 Feed format
-    Either *XML* or *JSON*.  The view decorators will automatically
-    detect and output the correct format.
+    Either *XML* or *JSON*.  If you don't specify a format the decorators will
+    automatically detect and output the correct format or default to XML 
+    if this is not enabled (by default the format isn't appended by 
+    Geckoboard as a parameter any more)
 
 Request type
     Either *GET* or *POST*.  The view decorators accept both.
@@ -354,6 +384,6 @@ http://support.geckoboard.com/entries/274940-custom-chart-widget-type-definition
 
 __author__ = "Joost Cassee"
 __email__ = "joost@cassee.net"
-__version__ = "1.2.6"
-__copyright__ = "Copyright (C) 2011 Joost Cassee and others"
+__version__ = "1.2.7"
+__copyright__ = "Copyright (C) 2011-2013 Joost Cassee and others"
 __license__ = "MIT License"
