@@ -50,6 +50,13 @@ class WidgetDecoratorTestCase(TestCase):
         self.assertEqual('Geckoboard API key incorrect', resp.content)
 
     def test_xml_get(self):
+        req = HttpRequest()
+        resp = widget(format="xml")(lambda r: "test")(req)
+        self.assertEqual('<?xml version="1.0" ?><root>test</root>',
+                resp.content)
+        self.assertEqual(resp._headers['content-type'], ('Content-Type', 'application/xml'))
+
+    def test_xml_parameter_get(self):
         req = HttpRequest()
         req.GET['format'] = '1'
         resp = widget(lambda r: "test")(req)
@@ -58,12 +65,38 @@ class WidgetDecoratorTestCase(TestCase):
         self.assertEqual(resp._headers['content-type'], ('Content-Type', 'application/xml'))
 
     def test_json_get(self):
+        req = HttpRequest()
+        resp = widget(format="json")(lambda r: "test")(req)
+        self.assertEqual('"test"', resp.content)
+        self.assertEqual(resp._headers['content-type'], ('Content-Type', 'application/json'))
+
+    def test_json_parameter_get(self):
         req = HttpRequest()
         req.GET['format'] = '2'
         resp = widget(lambda r: "test")(req)
         self.assertEqual('"test"', resp.content)
         self.assertEqual(resp._headers['content-type'], ('Content-Type', 'application/json'))
 
+    def test_wrong_format(self):
+        req = HttpRequest()
+        resp = widget(format="csv")(lambda r: "test")(req)
+        self.assertEqual('<?xml version="1.0" ?><root>test</root>',
+                resp.content)
+        self.assertEqual(resp._headers['content-type'], ('Content-Type', 'application/xml'))
+
+    def test_encrypted_xml_get(self):
+        req = HttpRequest()
+        req.GET['format'] = '1'
+        self.assertRaises(ValueError, widget(encrypted=True)(lambda r: "test"), req)
+
+    def test_encrypted_json_get(self):
+        req = HttpRequest()
+        req.GET['format'] = '2'
+        resp = widget(encrypted=True)(lambda r: "test")(req)
+        self.assertNotEqual('"test"', resp.content)
+        self.assertEqual(44, len(resp.content))
+        self.assertEqual(resp._headers['content-type'], ('Content-Type', 'application/json'))
+
     def test_xml_post(self):
         req = HttpRequest()
         req.POST['format'] = '1'
@@ -151,6 +184,14 @@ class NumberDecoratorTestCase(TestCase):
         json = '{"item": [{"value": 10}], "absolute": "true"}'
         self.assertEqual(json, resp.content)
 
+    def test_single_value_and_parameter_with_format(self):
+        # reset POST
+        del self.request.POST['format']
+        widget = number_widget(absolute='true', format="json")(lambda r: [10])
+        resp = widget(self.request)
+        json = '{"item": [{"value": 10}], "absolute": "true"}'
+        self.assertEqual(json, resp.content)
+
     def test_single_value_as_dictionary(self):
         widget = number_widget(lambda r: [{'value': 10}])
         resp = widget(self.request)
